@@ -368,8 +368,6 @@ PLAN_RESULT_SCHEMA = '''{
                         "reward",
                         "measurements",
                         "orders_count",
-                        "plan_orders_count",
-                        "waitlist_orders_count",
                         "performers_count"
                     ],
                     "type": "object"
@@ -755,8 +753,6 @@ PLAN_RESULT_SCHEMA = '''{
                                     "reward",
                                     "measurements",
                                     "orders_count",
-                                    "plan_orders_count",
-                                    "waitlist_orders_count",
                                     "performers_count"
                                 ],
                                 "type": "object"
@@ -1154,10 +1150,53 @@ PLAN_RESULT_SCHEMA = '''{
         "tracedata": {
             "additionalProperties": false,
             "properties": {
+                "client": {
+                    "maxLength": 256,
+                    "minLength": 2,
+                    "pattern": "\\w+",
+                    "type": "string"
+                },
                 "code": {
                     "maxLength": 256,
                     "minLength": 3,
                     "type": "string"
+                },
+                "method": {
+                    "enum": [
+                        "PLAN",
+                        "CONVERT",
+                        "ANALYTICS",
+                        "PREDICT",
+                        "ACTUALIZE",
+                        "VALIDATE",
+                        "ROUTE",
+                        "MATRIX",
+                        "CLUSTER"
+                    ],
+                    "type": "string"
+                },
+                "server": {
+                    "maxLength": 256,
+                    "minLength": 2,
+                    "type": "string"
+                },
+                "service": {
+                    "enum": [
+                        "LASTMILE",
+                        "DELIVERY",
+                        "FIELDSERVICE",
+                        "MERCHANDISER",
+                        "ROUTING",
+                        "CLUSTERING",
+                        "ACCOUNT",
+                        "STOCK",
+                        "ADMIN"
+                    ],
+                    "type": "string"
+                },
+                "time": {
+                    "format": "date-time",
+                    "type": "string"
                 }
             },
             "required": [
@@ -1338,7 +1377,7 @@ PLAN_RESULT_SCHEMA = '''{
                                         "type": "object"
                                     },
                                     "reward": {
-                                        "default": 1000,
+                                        "default": 1000.1,
                                         "format": "double",
                                         "maximum": 1000000,
                                         "minimum": 0,
