@@ -59,7 +59,7 @@ PLAN_TASK_SCHEMA = '''{
                                 "type": "object"
                             },
                             "reward": {
-                                "default": 1000,
+                                "default": 1000.1,
                                 "format": "double",
                                 "maximum": 1000000,
                                 "minimum": 0,
